package com.jz.dm.mall.moduls.controller.customer;

import com.jz.common.base.BaseController;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.service.MallCustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Map;

/**
 * 商城用户(MallCustomer)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:40
 */
@RestController
@RequestMapping("/mallCustomer")
public class MallCustomerController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private MallCustomerService mallCustomerService;

    @Autowired
    private RedisTemplate redisTemplate;


    /**
     * 手机号码校验
     * @param paramMap
     * @return
     */
    @PostMapping(value = "/check")
    public Result loginCheck(@RequestBody Map<String, String> paramMap) {
        // 获取手机号码
        String telephone = paramMap.get("telephone");
        String key = RedisMessageConstant.SENDTYPE_LOGIN + "_" + telephone;
        // 获取redis中key对应的值
        String codeInRedis = (String) redisTemplate.opsForValue().get(key);
        if (StringUtils.isEmpty(codeInRedis)) {
            return new Result(false, "请重新获取验证码!", StatusCode.ERROR);
        }
        // 判断验证码是否一致
        if (!codeInRedis.equals(paramMap.get("validateCode"))) {
            return new Result(false, "验证码不正确！", StatusCode.ERROR);
        }
        // 删除redis的验证码
        redisTemplate.delete(key);

        return new Result(true, "验证码正确！", StatusCode.OK);
    }


}